@@ -4,6 +4,9 @@
 This is file information, not the class information. This information is only for the API developers.
 Please read the 'Atom' object documentation for details.
 
+Citation:
+    Pranav M Khade, Robert L Jernigan, PACKMAN-Molecule: Python Toolbox for Structural Bioinformatics, Bioinformatics Advances, 2022;, vbac007, https://doi.org/10.1093/bioadv/vbac007
+
 Example::
 
     from packman.molecule import Atom
@@ -21,6 +24,10 @@ Authors:
 
 import numpy
 
+import logging
+
+from packman import molecule
+
 
 class Atom():
     """This class contains the information about the 'Atom' object (packman.molecule.Atom).
@@ -59,6 +66,7 @@ class Atom():
 
         #Properties are the entities that are not included in the PDB files and are obtained by calculations
         self.__properties = {}
+        self.__Bonds = []
 
     #Get Functions
     def get_id(self):
@@ -158,7 +166,7 @@ class Atom():
         return self.get_parent().get_domain_id()
     
     def get_property(self,property_name):
-        """Get the Property of the given 'Chain'.
+        """Get the Property of the given 'Atom'.
 
         Property is any key and value combination that can be assigned to this object. This (along with the set_property) feature is mainly useful for the user customization.
         Properties are like pinboards. You can pin anything to the object with a key as a pin.
@@ -173,6 +181,33 @@ class Atom():
             return self.__properties[property_name]
         except:
             logging.warning('The Property Name provided is not assigned.')
+    
+    def get_bonds(self):
+        """Get the bonds for the given 'Atom'
+
+        Returns:
+            list of packman.molecule.Bond if successful; [] otherwise.
+        """
+        return self.__Bonds
+    
+    def get_bond(self,atom2):
+        """Get the specific bond with the specific atom.
+
+        Args:
+            atom2 (packman.molecule.Atom/ int) : 'Atom' object or the atom id.
+
+        Returns:
+            Bond (packman.molecule.Bond) if successful, None if bond does not exist.
+        """
+        if(type(atom2) == type(self)):
+            None
+        elif(type(atom2) ==int):
+            Model = self.get_parent().get_parent().get_parent()
+            atom2 = Model.get_atom(atom2)
+        else:
+            logging.warning('The atom2 parameter should either be an integer (atom id) or a packman.molecule.Atom object.')
+
+        return list(set(self.get_bonds()).intersection( atom2.get_bonds() ))[0]
 
     #Set Functions
     def set_id(self,new_id):
@@ -273,6 +308,16 @@ class Atom():
         except:
             logging.warning('Please check the property name. Check the allowed Python dictionary key types for more details.')
 
+    def set_bond(self,new_bond):
+        """Set the atom to the given 'Atom'
+
+        Args:
+            new_bond (packman.molecule.Bond) : Add new bond to the given 'Atom'
+        
+        Note:
+            - Yet to add the functionality to delete the specific bonds.
+        """
+        self.__Bonds.append(new_bond)
 
     #Calculation Functions
     def calculate_distance(self,another_atom):
